@@ -1,7 +1,7 @@
 /* Native-dependent code for the i386.
 
-   Copyright (C) 2001, 2004, 2005, 2007, 2008, 2009, 2010, 2011
-   Free Software Foundation, Inc.
+   Copyright (C) 2001, 2004-2005, 2007-2012 Free Software Foundation,
+   Inc.
 
    This file is part of GDB.
 
